@@ -47,6 +47,6 @@ class RemoteCommand:
     def _run_command(cmd):
         cmd = cmd.split()
         logging.debug('command in list format:{}'.format(cmd))
-        output = subprocess.check_output(cmd, shell=False)
+        output = subprocess.check_output(cmd, shell=True)
         logging.info(f'response is {output} of type {type(output)}')
 
